@@ -2,17 +2,16 @@
 
 from __future__ import annotations
 
-import contextvars
 import logging
 
 
-__version__ = '0.13.0'
+__version__ = '0.13.2'
 
 
 logger: logging.Logger = logging.getLogger('aio-databases')
 logger.addHandler(logging.NullHandler())
 
-current_conn = contextvars.ContextVar('aio-db-ses', default=None)
 
+from .database import Database, current_conn
 
-from .database import Database  # noqa
+__all__ = 'Database', 'current_conn'
